# Sonos Artwork

Displays Sonos artwork on a HyperPixel 4.0 Square.

## Requirements

The Sonos HTTP API running somewhere: https://github.com/jishi/node-sonos-http-api

## Limitations

Only work with Sonos Radio and Apple Music.